@@ -6,34 +6,32 @@ known.designs <- function()
 # Nomenclature of replicate designs: treatments x sequences x periods
 # Note: the df for the replicate designs are those without carry-over.
 # Chen, Chow and Liu used models with carry-over, i.e. 1 df lower.
-# n is the total number of subjects in case of cross-over designs 
-# and is number of subjects per group in case of parallel group design.
+# n is the total number of subjects (cross-over designs and parallel group)
 # df2 = degrees of freedom for robust analysis (aka Senn's basic estimator).
-# bk is the so-called design constant, here in terms of total n, 
-# also without carry over.
-# In case of 2x2x4 design Chen, Chow and Liu used bk=1.1 (bk(ni)=11/40) 
-#  in a model with carry over.
+# bk is the so-called design constantin terms of total n, also without carry over.
+# bkni is the design constantin terms of n per sequence, also without carry over.
+# In case of 2x2x4 design Chen, Chow and Liu used bk=1.1 (bkni=11/40) 
+# in a model with carry over.
 # Dec2011: parallel group design now also for n=ntotal
 des <- ("
-no  design    df    df2  steps  bk   bkni
- 0  parallel n-2    n-2    2    4    1          
- 1  2x2      n-2    n-2    2    2    0.5        
- 1  2x2x2    n-2    n-2    2    2    0.5
- 2  3x3      2*n-4  n-3    3    2    0.22222222 # 2/9   3 sequence latin
- 3  3x6x3    2*n-4  n-6    6    2    0.05555555 # 1/18  6 sequence 'williams'
- 4  4x4      3*n-6  n-4    4    2    0.125      # 1/8   4 sequence 'williams'
- 5  2x2x3    2*n-3  n-2    2    1.5  0.375      # 3/8
- 6  2x2x4    3*n-4  n-2    2    1    0.25       # 1/4
- 7  2x4x4    3*n-4  n-4    4    1    0.0625     # 1/16
- 9  2x3x3    2*n-3  n-3    3    1.5  0.16666667 # 1/6
-10  2x4x2    n-2    n-2    4    8    0.5
-100 paired   n-1    n-1    1    2    0.5
+no  design    df    df2  steps  bk   bknif 
+ 0  parallel n-2    n-2    2    4    1/1             
+ 1  2x2      n-2    n-2    2    2    1/2           
+ 1  2x2x2    n-2    n-2    2    2    1/2   
+ 2  3x3      2*n-4  n-3    3    2    2/9   # 3 sequence latin
+ 3  3x6x3    2*n-4  n-6    6    2    1/18  # 6 sequence 'williams'
+ 4  4x4      3*n-6  n-4    4    2    1/8   # 4 sequence 'williams'
+ 5  2x2x3    2*n-3  n-2    2    1.5  3/8   
+ 6  2x2x4    3*n-4  n-2    2    1    1/4   
+ 7  2x4x4    3*n-4  n-4    4    1    1/16  
+ 9  2x3x3    2*n-3  n-3    3    1.5  1/6   
+10  2x4x2    n-2    n-2    4    8    1/2   # Balaam's design 
+100 paired   n-1    n-1    1    2    1/2   
 ")
 # no. 9 is f.i. the partial replicate design TRR/RTR/RRT
 # no. 10 is Balaam's design, a mixture of crossover and parallel group.
 # questionable df2 for Baalams design!
 #
-# eventually it would be better to have steps=6 in case of 3x3 (6 seq. design)
 # Jan 2011: 3x6x3 introduced, df for 3x3 corrected (former 2*n-3)
 # also df for 4x4 corrected (former 3*n-5)
 # Apr-2012: bk(ni) added for 3x3, 3x6x3 and 4x4
@@ -41,7 +39,10 @@ no  design    df    df2  steps  bk   bkni
   des2 <- textConnection(des)
   designs <- read.table(des2, header=TRUE, sep="", strip.white=TRUE, as.is=TRUE)           
   close(des2)   # without this close() warnings are generated
-	
+	# convert fractions to number
+  designs$bkni <- sapply(strsplit(designs$bknif,split="/"),
+                         function(x) as.numeric(x[1])/as.numeric(x[2])
+                         )
   # nicer names for nicer output of design
   designs$name[designs$no==0] <- "2 parallel groups"
   designs$name[designs$no %in% c(1,2,3,4)] <- 
