@@ -14,7 +14,7 @@
   n0 <- ceiling(bk*(se*tinv/(diffm - lmargin))^2)
   #make an even multiple of step (=2 in case of 2x2 cross-over)
   n0 <- steps*trunc(n0/steps)
-  if (n0<4) n0 <- 4   # minimum sample size
+  #if (n0<4) n0 <- 4   # minimum sample size will be tested outside
   
   return(n0)
 }
@@ -43,11 +43,17 @@ expsampleN.noninf <- function(alpha=0.025, targetpower=0.8, logscale=TRUE,
   }
   steps  <- ades$steps	# stepsize for sample size search
   bk     <- ades$bk # get design constant
+  # minimum sample size
+  df <- 0; n <- 0
+  while (df<1){
+    n  <- n + 1
+    df <- eval(dfe)
+  }
+  nmin <- n
   
   if (missing(CV) | missing(dfCV)) {
     stop("CV and its df must be given!", call.=FALSE)
   }
-  
   # calculate pooled data if CV and dfCV are vectors
   if (length(CV)>1){
     if (length(dfCV)!=length(CV)) {
@@ -135,6 +141,7 @@ expsampleN.noninf <- function(alpha=0.025, targetpower=0.8, logscale=TRUE,
   #start value from large sample approx. 
   n   <- .expsampleN0.noninf(alpha, targetpower, lmargin, diffm, 
                              se, dfse, steps, bk)
+  if(n<nmin) n <- nmin
   df  <- eval(dfe)
   pow <- .exppower.noninf(alpha, lmargin, diffm, se, dfse, n, df, bk) 
   if (details) {
@@ -153,7 +160,7 @@ expsampleN.noninf <- function(alpha=0.025, targetpower=0.8, logscale=TRUE,
   # starting with too high power should be rare sinsce the large sample
   # approximation should give too low sample size
   while (pow>targetpower) {
-    if (n<=4) { # min number
+    if (n<=nmin) { # min number
       if (print & iter==0) cat( n," ", formatC(pow, digits=6, format="f"),"\n")
       break
     }
@@ -173,12 +180,18 @@ expsampleN.noninf <- function(alpha=0.025, targetpower=0.8, logscale=TRUE,
     if (details) cat( n," ", formatC(pow, digits=6, format="f"),"\n")
     if (iter>imax) break 
   }
+  if (pow<targetpower) {
+    n <- NA
+    if (details) cat("Sample size search failed!\n")
+  }
+  
   if (print && !details) {
     cat("\nSample size (ntotal)\n")
     # parallel group design is now also handled in terms of ntotal
     #if (d.no == 0) cat("(n is sample size per group)\n") 
     cat(" n    exp. power\n")
     cat( n," ", formatC(pow, digits=6, format="f"),"\n")
+    if (is.na(n)) cat("Sample size search failed!\n")
   }
   
   if (print) cat("\n")
